Index
Date: 2017-11-20

A C D E G H I J M N O P R S T U V

## A

addIncludePaths(String...) - Method in class jep.JepConfig
  Adds a path of directories separated by File.pathSeparator that will be appended to the sub-intepreter's `sys.path`
addSharedModules(String...) - Method in class jep.JepConfig
  Adds module names to the set of shared modules
addTopLevelPackageName(String) - Method in class jep.NamingConventionClassEnquirer
  Adds a top level package name to the list of names that should be considered as Java packages

## C

ClassEnquirer - Interface in jep
  Interface to enquire if a name is available to be imported from Java.
classEnquirer - Variable in class jep.JepConfig
ClassList - Class in jep
  A singleton that searches for loaded classes from the JRE and the Java classpath.
classLoader - Variable in class jep.JepConfig
close() - Method in class jep.Jep
  Shuts down the Python sub-interpreter.
close() - Method in class jep.JepScriptEngine
  You *must* close this
createBindings() - Method in class jep.JepScriptEngine
  Describe `createBindings` method here.
createModule(String) - Method in class jep.Jep
  Create a Python module on the interpreter.

## D

DirectNDArray<T extends java.nio.Buffer> - Class in jep
  Represents a numpy.ndarray in Java.
DirectNDArray(T) - Constructor for class jep.DirectNDArray
  Constructor for a Java DirectNDArray.
DirectNDArray(T, boolean) - Constructor for class jep.DirectNDArray
  Constructor for a Java DirectNDArray.
DirectNDArray(T, int...) - Constructor for class jep.DirectNDArray
  Constructor for a Java DirectNDArray.
DirectNDArray(T, boolean, int...) - Constructor for class jep.DirectNDArray
  Constructor for a Java DirectNDArray.
dontWriteBytecodeFlag - Variable in class jep.PyConfig

## E

equals(Object) - Method in class jep.DirectNDArray
equals(Object) - Method in class jep.NDArray
eval(String) - Method in class jep.Jep
  Evaluate Python statements.
eval(Reader) - Method in class jep.JepScriptEngine
  Run script from reader.
eval(Reader, ScriptContext) - Method in class jep.JepScriptEngine
  Note: always returns null due to Python limitations.
eval(Reader, Bindings) - Method in class jep.JepScriptEngine
  Note: always returns null due to Python limitations.
eval(String) - Method in class jep.JepScriptEngine
  Note: always returns null due to Python limitations.
eval(String, ScriptContext) - Method in class jep.JepScriptEngine
  Describe `eval` method here.
eval(String, Bindings) - Method in class jep.JepScriptEngine
  Describe `eval` method here.

## G

get(String) - Method in class jep.JepScriptEngine
  Describe `get` method here.
getBindings(int) - Method in class jep.JepScriptEngine
  Describe `getBindings` method here.
getClassNames(String) - Method in interface jep.ClassEnquirer
  Given a Java package name, gets the fully-qualified classnames available for import in the package.
getClassNames(String) - Method in class jep.ClassList
  get classnames in package
getClassNames(String) - Method in class jep.NamingConventionClassEnquirer
getContext() - Method in class jep.JepScriptEngine
  Describe `getContext` method here.
getEngineName() - Method in class jep.JepScriptEngineFactory
  Describe `getEngineName` method here.
getEngineVersion() - Method in class jep.JepScriptEngineFactory
  Describe `getEngineVersion` method here.
getExtensions() - Method in class jep.JepScriptEngineFactory
  (non-Javadoc)
getFactory() - Method in class jep.JepScriptEngine
  Describe `getFactory` method here.
getInstance() - Static method in class jep.ClassList
  get ClassList instance
getLanguageName() - Method in class jep.JepScriptEngineFactory
  Describe `getLanguageName` method here.
getLanguageVersion() - Method in class jep.JepScriptEngineFactory
  Describe `getLanguageVersion` method here.
getLength(T) - Method in class jep.DirectNDArray
getLength(T) - Method in class jep.NDArray
getMethodCallSyntax(String, String, String[]) - Method in class jep.JepScriptEngineFactory
  Describe `getMethodCallSyntax` method here.
getMimeTypes() - Method in class jep.JepScriptEngineFactory
  (non-Javadoc)
getNames() - Method in class jep.JepScriptEngineFactory
  (non-Javadoc)
getOutputStatement(String) - Method in class jep.JepScriptEngineFactory
  Describe `getOutputStatement` method here.
getParameter(String) - Method in class jep.JepScriptEngineFactory
  Describe `getParameter` method here.
getProgram(String[]) - Method in class jep.JepScriptEngineFactory
  Describe `getProgram` method here.
getPythonType() - Method in exception jep.JepException
  Get the address of the python exception type that triggered this exceptions.
getScriptEngine() - Method in class jep.JepScriptEngineFactory
  Describe `getScriptEngine` method here.
getSubPackages(String) - Method in interface jep.ClassEnquirer
  Given a Java package name, gets the sub-packages available.
getSubPackages(String) - Method in class jep.ClassList
getSubPackages(String) - Method in class jep.NamingConventionClassEnquirer
getTypeId(Object) - Static method in class jep.Util
  Internal use only Does the same thing as util.c::get_jtype, but it's easier more stable to do this in java when able.
getTypeId(Class<?>) - Static method in class jep.Util
  Internal use only Same as `getTypeId(Object)` but for Class.
getValue(String) - Method in class jep.Jep
  Retrieves a value from this Python sub-interpreter.
getValue_bytearray(String) - Method in class jep.Jep
  Retrieves a Python string object as a Java byte[].

## H

hashCode() - Method in class jep.DirectNDArray
hashCode() - Method in class jep.NDArray
hashRandomizationFlag - Variable in class jep.PyConfig

## I

ignoreEnvironmentFlag - Variable in class jep.PyConfig
includePath - Variable in class jep.JepConfig
interactive - Variable in class jep.JepConfig
InvocationHandler - Class in jep
  Handle Proxy method calls.
InvocationHandler(long, long, Jep, boolean) - Constructor for class jep.InvocationHandler
  Creates a new `InvocationHandler` instance.
invoke(Object, Method, Object[]) - Method in class jep.InvocationHandler
  Processes a method invocation on a proxy instance and returns the result.
invoke(String, Object...) - Method in class jep.Jep
  Invokes a Python function.
isInteractive() - Method in class jep.Jep
  Gets whether or not this sub-interpreter is interactive.
isJavaPackage(String) - Method in interface jep.ClassEnquirer
  Checks if the name is likely available in Java as a package.
isJavaPackage(String) - Method in class jep.ClassList
  Checks if the String is known to the ClassList as an available package
isJavaPackage(String) - Method in class jep.NamingConventionClassEnquirer
isValidThread() - Method in class jep.Jep
  Checks if the current thread is valid for the method call.

## J

JARRAY_ID - Static variable in class jep.Util
javaNames - Variable in class jep.NamingConventionClassEnquirer
JBOOLEAN_ID - Static variable in class jep.Util
JBYTE_ID - Static variable in class jep.Util
JCHAR_ID - Static variable in class jep.Util
JCLASS_ID - Static variable in class jep.Util
JDOUBLE_ID - Static variable in class jep.Util
jep - package jep
Jep - Class in jep
  Embeds CPython in Java.
Jep() - Constructor for class jep.Jep
  Creates a new `Jep` instance and its associated sub-interpreter.
Jep(boolean) - Constructor for class jep.Jep
  Creates a new `Jep` instance and its associated sub-interpreter.
Jep(boolean, String) - Constructor for class jep.Jep
  Creates a new `Jep` instance and its associated sub-interpreter.
Jep(boolean, String, ClassLoader) - Constructor for class jep.Jep
  Creates a new `Jep` instance and its associated sub-interpreter.
Jep(boolean, String, ClassLoader, ClassEnquirer) - Constructor for class jep.Jep
  Creates a new `Jep` instance and its associated sub-interpreter.
Jep(JepConfig) - Constructor for class jep.Jep
JepConfig - Class in jep
  A configuration object for constructing a Jep instance, corresponding to the configuration of the particular Python sub-interpreter.
JepConfig() - Constructor for class jep.JepConfig
JepException - Exception in jep
  JepException - it happens.
JepException() - Constructor for exception jep.JepException
  Creates a new `JepException` instance.
JepException(String) - Constructor for exception jep.JepException
  Creates a new `JepException` instance.
JepException(Throwable) - Constructor for exception jep.JepException
  Creates a new `JepException` instance.
JepException(String, Throwable) - Constructor for exception jep.JepException
  Creates a new `JepException` instance.
JepException(String, long) - Constructor for exception jep.JepException
  Construct with the address of a python exception type.
JepScriptEngine - Class in jep
  Implements `ScriptEngine`
JepScriptEngine() - Constructor for class jep.JepScriptEngine
  Make a new JepScriptEngine
JepScriptEngineFactory - Class in jep
  Implements `ScriptEngineFactory`
JepScriptEngineFactory() - Constructor for class jep.JepScriptEngineFactory
JFLOAT_ID - Static variable in class jep.Util
JINT_ID - Static variable in class jep.Util
JLONG_ID - Static variable in class jep.Util
JOBJECT_ID - Static variable in class jep.Util
JSHORT_ID - Static variable in class jep.Util
JSTRING_ID - Static variable in class jep.Util
JVOID_ID - Static variable in class jep.Util

## M

main(String[]) - Static method in class jep.ClassList
  for testing only
main(String[]) - Static method in class jep.Run
  Describe `main` method here.

## N

NamingConventionClassEnquirer - Class in jep
  A simple `ClassEnquirer` to see if the package/class to be imported in a Python sub-interpreter should be considered as a Java package/class.
NamingConventionClassEnquirer() - Constructor for class jep.NamingConventionClassEnquirer
  Convenience constructor.
NamingConventionClassEnquirer(boolean) - Constructor for class jep.NamingConventionClassEnquirer
  Constructor
NamingConventionClassEnquirer(boolean, boolean) - Constructor for class jep.NamingConventionClassEnquirer
  Constructor
NDArray<T> - Class in jep
  Represents a numpy.ndarray in Java.
NDArray(T) - Constructor for class jep.NDArray
  Constructor for a Java NDArray.
NDArray(T, boolean) - Constructor for class jep.NDArray
  Constructor for a Java NDArray.
NDArray(T, int...) - Constructor for class jep.NDArray
  Constructor for a Java NDArray.
NDArray(T, boolean, int...) - Constructor for class jep.NDArray
  Constructor for a Java NDArray.
newProxyInstance(long, long, Jep, ClassLoader, String[]) - Static method in class jep.Proxy
  Returns an instance of a proxy class for the specified interfaces that dispatches method invocations to the specified invocation handler.
noSiteFlag - Variable in class jep.PyConfig
noUserSiteDirectory - Variable in class jep.PyConfig

## O

optimizeFlag - Variable in class jep.PyConfig

## P

Proxy - Class in jep
  Extends java.lang.reflect.Proxy for callbacks.
Proxy(InvocationHandler) - Constructor for class jep.Proxy
  Constructs a new Proxy instance from a subclass (typically, a dynamic proxy class) with the specified value for its invocation handler.
put(String, Object) - Method in class jep.JepScriptEngine
  Describe `put` method here.
PyConfig - Class in jep
  A configuration object for setting Python pre-initialization parameters.
PyConfig() - Constructor for class jep.PyConfig

## R

redirectOutputStreams - Variable in class jep.JepConfig
RESTRICTED_PKG_NAMES - Static variable in interface jep.ClassEnquirer
  Certain Java libraries (e.g.
Run - Class in jep
  Executes a Python script in a Jep sub-interpreter.
run(boolean) - Static method in class jep.Run
runScript(String) - Method in class jep.Jep
  Runs a Python script.
runScript(String, ClassLoader) - Method in class jep.Jep
  Runs a Python script.

## S

set(String, Object) - Method in class jep.Jep
  Sets the Java Object into the sub-interpreter's global scope with the specified variable name.
set(String, String) - Method in class jep.Jep
  Sets the Java String into the sub-interpreter's global scope with the specified variable name.
set(String, boolean) - Method in class jep.Jep
  Sets the Java boolean into the sub-interpreter's global scope with the specified variable name.
set(String, int) - Method in class jep.Jep
  Sets the Java int into the sub-interpreter's global scope with the specified variable name.
set(String, short) - Method in class jep.Jep
  Sets the Java short into the sub-interpreter's global scope with the specified variable name.
set(String, char[]) - Method in class jep.Jep
  Sets the Java char[] into the sub-interpreter's global scope with the specified variable name.
set(String, char) - Method in class jep.Jep
  Sets the Java char into the sub-interpreter's global scope with the specified variable name.
set(String, byte) - Method in class jep.Jep
  Sets the Java byte into the sub-interpreter's global scope with the specified variable name.
set(String, long) - Method in class jep.Jep
  Sets the Java long into the sub-interpreter's global scope with the specified variable name.
set(String, double) - Method in class jep.Jep
  Sets the Java double into the sub-interpreter's global scope with the specified variable name.
set(String, float) - Method in class jep.Jep
  Sets the Java float into the sub-interpreter's global scope with the specified variable name.
set(String, boolean[]) - Method in class jep.Jep
  Sets the Java boolean[] into the sub-interpreter's global scope with the specified variable name.
set(String, int[]) - Method in class jep.Jep
  Sets the Java int[] into the sub-interpreter's global scope with the specified variable name.
set(String, short[]) - Method in class jep.Jep
  Sets the Java short[] into the sub-interpreter's global scope with the specified variable name.
set(String, byte[]) - Method in class jep.Jep
  Sets the Java byte[] into the sub-interpreter's global scope with the specified variable name.
set(String, long[]) - Method in class jep.Jep
  Sets the Java long[] into the sub-interpreter's global scope with the specified variable name.
set(String, double[]) - Method in class jep.Jep
  Sets the Java double[] into the sub-interpreter's global scope with the specified variable name.
set(String, float[]) - Method in class jep.Jep
  Sets the Java float[] into the sub-interpreter's global scope with the specified variable name.
setBindings(Bindings, int) - Method in class jep.JepScriptEngine
  Describe `setBindings` method here.
setClassEnquirer(ClassEnquirer) - Method in class jep.JepConfig
  Sets a ClassEnquirer to determine which imports are Python vs Java, or null for the default `ClassList`
setClassLoader(ClassLoader) - Method in class jep.Jep
  Sets the default classloader.
setClassLoader(ClassLoader) - Method in class jep.JepConfig
  Sets the ClassLoader to use when importing Java classes from Python
setContext(ScriptContext) - Method in class jep.JepScriptEngine
  Describe `setContext` method here.
setDontWriteBytecodeFlag(int) - Method in class jep.PyConfig
  Set the Py_DontWriteBytecodeFlag variable on the python interpreter.
setFactory(ScriptEngineFactory) - Method in class jep.JepScriptEngine
  For internal use.
setHashRandomizationFlag(int) - Method in class jep.PyConfig
  Set the Py_HashRandomizationFlag variable on the python interpreter.
setIgnoreEnvironmentFlag(int) - Method in class jep.PyConfig
  Set the Py_IgnoreEnvironmentFlag variable on the python interpreter.
setIncludePath(String) - Method in class jep.JepConfig
  Sets a path of directories separated by File.pathSeparator that will be appended to the sub-intepreter's `sys.path`
setInitParams(PyConfig) - Static method in class jep.Jep
  Sets interpreter settings for the top Python interpreter.
setInteractive(boolean) - Method in class jep.Jep
  Changes behavior of `Jep.eval(String)`.
setInteractive(boolean) - Method in class jep.JepConfig
  Sets whether `Jep.eval(String)` should support the slower behavior of potentially waiting for multiple statements
setNoSiteFlag(int) - Method in class jep.PyConfig
  Set the Py_NoSiteFlag variable on the python interpreter.
setNoUserSiteDirectory(int) - Method in class jep.PyConfig
  Set the Py_NoUserSiteDirectory variable on the python interpreter.
setOptimizeFlag(int) - Method in class jep.PyConfig
  Set the Py_OptimizeFlag variable on the python interpreter.
setRedirectOutputStreams(boolean) - Method in class jep.JepConfig
  Sets whether to redirect the Python sys.stdout and sys.stderr streams to the Java System.out and System.err streams
setSharedModules(Set<String>) - Method in class jep.JepConfig
  Sets the names of modules which should be shared with other Jep sub-interpreters.
setSharedModulesArgv(String...) - Static method in class jep.Jep
  Sets the sys.argv values on the top interpreter.
setVerboseFlag(int) - Method in class jep.PyConfig
  Set the Py_VerboseFlag variable on the python interpreter.
sharedModules - Variable in class jep.JepConfig

## T

TOP_LEVEL - Static variable in class jep.NamingConventionClassEnquirer
  the default top level package names: java, javax, com, gov, org, edu, mil, net
trackObject(PyObject) - Method in class jep.Jep
  Track Python objects we create so they can be smoothly shutdown with no risk of crashes due to bad reference counting.
trackObject(PyObject, boolean) - Method in class jep.Jep
  Track Python objects we create so they can be smoothly shutdown with no risk of crashes due to bad reference counting.

## U

Util - Class in jep
  Utility functions

## V

validate(T) - Method in class jep.DirectNDArray
validate(T) - Method in class jep.NDArray
verboseFlag - Variable in class jep.PyConfig

A C D E G H I J M N O P R S T U V